@@ -3,11 +3,11 @@
 
 #define VBOX_VERSION_MAJOR 6
 #define VBOX_VERSION_MINOR 1
-#define VBOX_VERSION_BUILD 0
-#define VBOX_VERSION_STRING_RAW "6.1.0"
-#define VBOX_VERSION_STRING "6.1.0"
+#define VBOX_VERSION_BUILD 14
+#define VBOX_VERSION_STRING_RAW "6.1.14"
+#define VBOX_VERSION_STRING "6.1.14"
 #define VBOX_API_VERSION_STRING "6_1"
 
-#define VBOX_PRIVATE_BUILD_DESC "Private build by builder"
+#define VBOX_PRIVATE_BUILD_DESC "Private build by s8321414"
 
 #endif
