@@ -35,7 +35,92 @@
 #endif
 
 #include <linux/version.h>
-#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 5, 0)
+
+/* iprt/linux/version.h copy - start */
+/** @def RTLNX_VER_MIN
+ * Evaluates to true if the linux kernel version is equal or higher to the
+ * one specfied. */
+#define RTLNX_VER_MIN(a_Major, a_Minor, a_Patch) \
+	(LINUX_VERSION_CODE >= KERNEL_VERSION(a_Major, a_Minor, a_Patch))
+
+/** @def RTLNX_VER_MAX
+ * Evaluates to true if the linux kernel version is less to the one specfied
+ * (exclusive). */
+#define RTLNX_VER_MAX(a_Major, a_Minor, a_Patch) \
+	(LINUX_VERSION_CODE < KERNEL_VERSION(a_Major, a_Minor, a_Patch))
+
+/** @def RTLNX_VER_RANGE
+ * Evaluates to true if the linux kernel version is equal or higher to the given
+ * minimum version and less (but not equal) to the maximum version (exclusive). */
+#define RTLNX_VER_RANGE(a_MajorMin, a_MinorMin, a_PatchMin,  a_MajorMax, a_MinorMax, a_PatchMax) \
+	(   LINUX_VERSION_CODE >= KERNEL_VERSION(a_MajorMin, a_MinorMin, a_PatchMin) \
+	 && LINUX_VERSION_CODE <  KERNEL_VERSION(a_MajorMax, a_MinorMax, a_PatchMax) )
+
+
+/** @def RTLNX_RHEL_MIN
+ * Require a minium RedHat release.
+ * @param a_iMajor      The major release number (RHEL_MAJOR).
+ * @param a_iMinor      The minor release number (RHEL_MINOR).
+ * @sa RTLNX_RHEL_MAX, RTLNX_RHEL_RANGE, RTLNX_RHEL_MAJ_PREREQ
+ */
+#if defined(RHEL_MAJOR) && defined(RHEL_MINOR)
+# define RTLNX_RHEL_MIN(a_iMajor, a_iMinor) \
+	 ((RHEL_MAJOR) > (a_iMajor) || ((RHEL_MAJOR) == (a_iMajor) && (RHEL_MINOR) >= (a_iMinor)))
+#else
+# define RTLNX_RHEL_MIN(a_iMajor, a_iMinor) (0)
+#endif
+
+/** @def RTLNX_RHEL_MAX
+ * Require a maximum RedHat release, true for all RHEL versions below it.
+ * @param a_iMajor      The major release number (RHEL_MAJOR).
+ * @param a_iMinor      The minor release number (RHEL_MINOR).
+ * @sa RTLNX_RHEL_MIN, RTLNX_RHEL_RANGE, RTLNX_RHEL_MAJ_PREREQ
+ */
+#if defined(RHEL_MAJOR) && defined(RHEL_MINOR)
+# define RTLNX_RHEL_MAX(a_iMajor, a_iMinor) \
+	 ((RHEL_MAJOR) < (a_iMajor) || ((RHEL_MAJOR) == (a_iMajor) && (RHEL_MINOR) < (a_iMinor)))
+#else
+# define RTLNX_RHEL_MAX(a_iMajor, a_iMinor) (0)
+#endif
+
+/** @def RTLNX_RHEL_RANGE
+ * Check that it's a RedHat kernel in the given version range.
+ * The max version is exclusive, the minimum inclusive.
+ * @sa RTLNX_RHEL_MIN, RTLNX_RHEL_MAX, RTLNX_RHEL_MAJ_PREREQ
+ */
+#if defined(RHEL_MAJOR) && defined(RHEL_MINOR)
+# define RTLNX_RHEL_RANGE(a_iMajorMin, a_iMinorMin,  a_iMajorMax, a_iMinorMax) \
+	 (RTLNX_RHEL_MIN(a_iMajorMin, a_iMinorMin) && RTLNX_RHEL_MAX(a_iMajorMax, a_iMinorMax))
+#else
+# define RTLNX_RHEL_RANGE(a_iMajorMin, a_iMinorMin,  a_iMajorMax, a_iMinorMax)  (0)
+#endif
+
+/** @def RTLNX_RHEL_MAJ_PREREQ
+ * Require a minimum minor release number for the given RedHat release.
+ * @param a_iMajor      RHEL_MAJOR must _equal_ this.
+ * @param a_iMinor      RHEL_MINOR must be greater or equal to this.
+ * @sa RTLNX_RHEL_MIN, RTLNX_RHEL_MAX
+ */
+#if defined(RHEL_MAJOR) && defined(RHEL_MINOR)
+# define RTLNX_RHEL_MAJ_PREREQ(a_iMajor, a_iMinor) ((RHEL_MAJOR) == (a_iMajor) && (RHEL_MINOR) >= (a_iMinor))
+#else
+# define RTLNX_RHEL_MAJ_PREREQ(a_iMajor, a_iMinor) (0)
+#endif
+
+
+/** @def RTLNX_SUSE_MAJ_PREREQ
+ * Require a minimum minor release number for the given SUSE release.
+ * @param a_iMajor      CONFIG_SUSE_VERSION must _equal_ this.
+ * @param a_iMinor      CONFIG_SUSE_PATCHLEVEL must be greater or equal to this.
+ */
+#if defined(CONFIG_SUSE_VERSION) && defined(CONFIG_SUSE_PATCHLEVEL)
+# define RTLNX_SUSE_MAJ_PREREQ(a_iMajor, a_iMinor) ((CONFIG_SUSE_VERSION) == (a_iMajor) && (CONFIG_SUSE_PATCHLEVEL) >= (a_iMinor))
+#else
+# define RTLNX_SUSE_MAJ_PREREQ(a_iMajor, a_iMinor) (0)
+#endif
+/* iprt/linux/version.h copy - end */
+
+#if RTLNX_VER_MAX(4,5,0)
 # include <linux/types.h>
 # include <linux/spinlock_types.h>
 #endif
@@ -45,49 +130,8 @@
 #include <linux/string.h>
 #include <linux/pci.h>
 
-#if defined(RHEL_MAJOR) && defined(RHEL_MINOR)
-# if RHEL_MAJOR == 8 && RHEL_MINOR >= 2
-#  define RHEL_82
-# endif
-# if RHEL_MAJOR == 8 && RHEL_MINOR >= 1
-#  define RHEL_81
-# endif
-# if RHEL_MAJOR == 8 && RHEL_MINOR >= 0
-#  define RHEL_80
-# endif
-# if RHEL_MAJOR == 7 && RHEL_MINOR >= 7
-#  define RHEL_77
-# endif
-# if RHEL_MAJOR == 7 && RHEL_MINOR >= 6
-#  define RHEL_76
-# endif
-# if RHEL_MAJOR == 7 && RHEL_MINOR >= 5
-#  define RHEL_75
-# endif
-# if RHEL_MAJOR == 7 && RHEL_MINOR >= 4
-#  define RHEL_74
-# endif
-# if RHEL_MAJOR == 7 && RHEL_MINOR >= 3
-#  define RHEL_73
-# endif
-# if RHEL_MAJOR == 7 && RHEL_MINOR >= 2
-#  define RHEL_72
-# endif
-# if RHEL_MAJOR == 7 && RHEL_MINOR >= 1
-#  define RHEL_71
-# endif
-# if RHEL_MAJOR == 7 && RHEL_MINOR >= 0
-#  define RHEL_70
-# endif
-#endif
 
-#if defined(CONFIG_SUSE_VERSION)
-# if CONFIG_SUSE_VERSION == 15 && CONFIG_SUSE_PATCHLEVEL == 1
-#  define OPENSUSE_151
-# endif
-#endif
-
-#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 14, 0) || defined(RHEL_71)
+#if RTLNX_VER_MAX(3,14,0) || RTLNX_RHEL_MAJ_PREREQ(7,1)
 #define U8_MAX          ((u8)~0U)
 #define S8_MAX          ((s8)(U8_MAX>>1))
 #define S8_MIN          ((s8)(-S8_MAX - 1))
@@ -102,23 +146,23 @@
 #define S64_MIN         ((s64)(-S64_MAX - 1))
 #endif
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(5, 5, 0)
-#include <drm/drmP.h>
-#else /* >= KERNEL_VERSION(5, 5, 0) */
-#include <drm/drm_file.h>
-#include <drm/drm_drv.h>
-#include <drm/drm_device.h>
-#include <drm/drm_ioctl.h>
-#include <drm/drm_fourcc.h>
-#include <drm/drm_irq.h>
-#include <drm/drm_vblank.h>
-#endif /* >= KERNEL_VERSION(5, 5, 0) */
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 11, 0) || defined(RHEL_75)
-#include <drm/drm_encoder.h>
+#if RTLNX_VER_MAX(5,5,0)
+# include <drm/drmP.h>
+#else /* >= 5.5.0 */
+# include <drm/drm_file.h>
+# include <drm/drm_drv.h>
+# include <drm/drm_device.h>
+# include <drm/drm_ioctl.h>
+# include <drm/drm_fourcc.h>
+# include <drm/drm_irq.h>
+# include <drm/drm_vblank.h>
+#endif /* >= 5.5.0 */
+#if RTLNX_VER_MIN(4,11,0) || RTLNX_RHEL_MAJ_PREREQ(7,5)
+# include <drm/drm_encoder.h>
 #endif
 #include <drm/drm_fb_helper.h>
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(3, 18, 0) || defined(RHEL_72)
-#include <drm/drm_gem.h>
+#if RTLNX_VER_MIN(3,18,0) || RTLNX_RHEL_MAJ_PREREQ(7,2)
+# include <drm/drm_gem.h>
 #endif
 
 #include <drm/ttm/ttm_bo_api.h>
@@ -133,14 +177,14 @@
 
 #include "product-generated.h"
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 12, 0) && !defined(RHEL_75)
+#if RTLNX_VER_MAX(4,12,0) && !RTLNX_RHEL_MAJ_PREREQ(7,5)
 static inline void drm_gem_object_put_unlocked(struct drm_gem_object *obj)
 {
 	drm_gem_object_unreference_unlocked(obj);
 }
 #endif
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 12, 0) && !defined(RHEL_75)
+#if RTLNX_VER_MAX(4,12,0) && !RTLNX_RHEL_MAJ_PREREQ(7,5)
 static inline void drm_gem_object_put(struct drm_gem_object *obj)
 {
 	drm_gem_object_unreference(obj);
@@ -174,7 +218,7 @@ static inline void drm_gem_object_put(struct drm_gem_object *obj)
 /** How frequently we refresh if the guest is not providing dirty rectangles. */
 #define VBOX_REFRESH_PERIOD (HZ / 2)
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 13, 0) && !defined(RHEL_72)
+#if RTLNX_VER_MAX(3,13,0) && !RTLNX_RHEL_MAJ_PREREQ(7,2)
 static inline void *devm_kcalloc(struct device *dev, size_t n, size_t size,
 				 gfp_t flags)
 {
@@ -205,7 +249,7 @@ struct vbox_private {
 	int fb_mtrr;
 
 	struct {
-#if LINUX_VERSION_CODE < KERNEL_VERSION(5, 0, 0) && !defined(RHEL_77) && !defined(RHEL_81)
+#if RTLNX_VER_MAX(5,0,0) && !RTLNX_RHEL_MAJ_PREREQ(7,7) && !RTLNX_RHEL_MAJ_PREREQ(8,1)
 		struct drm_global_reference mem_global_ref;
 		struct ttm_bo_global_ref bo_global_ref;
 #endif
@@ -249,12 +293,12 @@ struct vbox_private {
 #undef CURSOR_PIXEL_COUNT
 #undef CURSOR_DATA_SIZE
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 19, 0)
+#if RTLNX_VER_MAX(4,19,0)
 int vbox_driver_load(struct drm_device *dev, unsigned long flags);
 #else
 int vbox_driver_load(struct drm_device *dev);
 #endif
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 11, 0) || defined(RHEL_75)
+#if RTLNX_VER_MIN(4,11,0) || RTLNX_RHEL_MAJ_PREREQ(7,5)
 void vbox_driver_unload(struct drm_device *dev);
 #else
 int vbox_driver_unload(struct drm_device *dev);
@@ -316,16 +360,16 @@ struct vbox_fbdev {
 int vbox_mode_init(struct drm_device *dev);
 void vbox_mode_fini(struct drm_device *dev);
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 3, 0)
-#define DRM_MODE_FB_CMD drm_mode_fb_cmd
+#if RTLNX_VER_MAX(3,3,0)
+# define DRM_MODE_FB_CMD drm_mode_fb_cmd
 #else
-#define DRM_MODE_FB_CMD drm_mode_fb_cmd2
+# define DRM_MODE_FB_CMD drm_mode_fb_cmd2
 #endif
 
-#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 15, 0) && !defined(RHEL_71)
-#define CRTC_FB(crtc) ((crtc)->fb)
+#if RTLNX_VER_MAX(3,15,0) && !RTLNX_RHEL_MAJ_PREREQ(7,1)
+# define CRTC_FB(crtc) ((crtc)->fb)
 #else
-#define CRTC_FB(crtc) ((crtc)->primary->fb)
+# define CRTC_FB(crtc) ((crtc)->primary->fb)
 #endif
 
 void vbox_enable_accel(struct vbox_private *vbox);
@@ -338,7 +382,7 @@ void vbox_framebuffer_dirty_rectangles(struct drm_framebuffer *fb,
 
 int vbox_framebuffer_init(struct drm_device *dev,
 			  struct vbox_framebuffer *vbox_fb,
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 5, 0) || defined(RHEL_73)
+#if RTLNX_VER_MIN(4,5,0) || RTLNX_RHEL_MAJ_PREREQ(7,3)
 			  const struct DRM_MODE_FB_CMD *mode_cmd,
 #else
 			  struct DRM_MODE_FB_CMD *mode_cmd,
@@ -354,7 +398,7 @@ struct vbox_bo {
 	struct ttm_placement placement;
 	struct ttm_bo_kmap_obj kmap;
 	struct drm_gem_object gem;
-#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 18, 0) && !defined(RHEL_72)
+#if RTLNX_VER_MAX(3,18,0) && !RTLNX_RHEL_MAJ_PREREQ(7,2)
 	u32 placements[3];
 #else
 	struct ttm_place placements[3];
@@ -374,7 +418,7 @@ static inline struct vbox_bo *vbox_bo(struct ttm_buffer_object *bo)
 int vbox_dumb_create(struct drm_file *file,
 		     struct drm_device *dev,
 		     struct drm_mode_create_dumb *args);
-#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 12, 0) && !defined(RHEL_73)
+#if RTLNX_VER_MAX(3,12,0) && !RTLNX_RHEL_MAJ_PREREQ(7,3)
 int vbox_dumb_destroy(struct drm_file *file,
 		      struct drm_device *dev, u32 handle);
 #endif
@@ -402,7 +446,7 @@ static inline int vbox_bo_reserve(struct vbox_bo *bo, bool no_wait)
 {
 	int ret;
 
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 7, 0) || defined(RHEL_74)
+#if RTLNX_VER_MIN(4,7,0) || RTLNX_RHEL_MAJ_PREREQ(7,4)
 	ret = ttm_bo_reserve(&bo->bo, true, no_wait, NULL);
 #else
 	ret = ttm_bo_reserve(&bo->bo, true, no_wait, false, 0);
@@ -428,7 +472,7 @@ int vbox_mmap(struct file *filp, struct vm_area_struct *vma);
 int vbox_gem_prime_pin(struct drm_gem_object *obj);
 void vbox_gem_prime_unpin(struct drm_gem_object *obj);
 struct sg_table *vbox_gem_prime_get_sg_table(struct drm_gem_object *obj);
-#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 18, 0) && !defined(RHEL_72)
+#if RTLNX_VER_MAX(3,18,0) && !RTLNX_RHEL_MAJ_PREREQ(7,2)
 struct drm_gem_object *vbox_gem_prime_import_sg_table(
 	struct drm_device *dev, size_t size, struct sg_table *table);
 #else
